# 🇹🇼 Taiwan Invoice

[![PyPI](https://img.shields.io/pypi/v/tw_invoice?color=brightgreen&logo=pypi&logoColor=white)](https://pypi.org/project/tw_invoice)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tw_invoice?color=brightgreen&logo=python&logoColor=white)
![PyPI - Downloads](https://img.shields.io/pypi/dm/tw_invoice?color=brightgreen)
![PyPI - License](https://img.shields.io/pypi/l/tw_invoice?color=brightgreen)

[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/tomy0000000/tw-invoice/test.yml?branch=main&logo=Github)](https://github.com/tomy0000000/tw-invoice/actions/workflows/test.yml)
[![Coverage](https://img.shields.io/codecov/c/github/tomy0000000/tw-invoice?color=brightgreen&logo=codecov&logoColor=white&token=ESgHfrrk6z)](https://codecov.io/gh/tomy0000000/tw-invoice)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/tomy0000000/tw-invoice/main.svg)](https://results.pre-commit.ci/latest/github/tomy0000000/tw-invoice/main)

[English README](https://github.com/tomy0000000/tw-invoice/blob/main/README.md)

財政部[電子發票整合服務平台](https://www.einvoice.nat.gov.tw) SDK

## 使用說明

請見 [Wiki](https://github.com/tomy0000000/tw-invoice/wiki)

## 授權及免責聲明

本軟體原始碼在 MIT 授權條款下發布，在版本號未移除 b (即測試版 beta) 後綴前皆為不穩定狀態，使用者需自負風險。

本軟體作者並不附屬或受僱於財政部及其平台。
